==> haskell-http-streams-0.8.6.1-59-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-761yOLK4jcV9ylK4i9DszM
key: http-streams-0.8.6.1-761yOLK4jcV9ylK4i9DszM
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 942975e7954c82757e699e303c3d0693
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-761yOLK4jcV9ylK4i9DszM
depends:
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-EXYgzwVXtzcKQ8mQHSCEPR
    HsOpenSSL-0.11.4.15-Diy411ZmHUaFaxsiImjV1e
    openssl-streams-1.2.1.3-D3UkbN5z33SIHSTyyD4o8G mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    http-common-0.8.2.0-2JbFpEHPVJPIEgp7t8cUZB
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu
abi-depends: attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             io-streams-1.5.0.1-EXYgzwVXtzcKQ8mQHSCEPR=d160931c42329e0f3edfb55d5bc08279
             HsOpenSSL-0.11.4.15-Diy411ZmHUaFaxsiImjV1e=daaf99750e17b41a4f3e2428a6948ff4
             openssl-streams-1.2.1.3-D3UkbN5z33SIHSTyyD4o8G=f0a257963c8664169b20270fbc87f14b
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             http-common-0.8.2.0-2JbFpEHPVJPIEgp7t8cUZB=ab53cb86167686aeb27bcb3c29b1712a
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.7.0.2-CxFtLVxZlCwGfUj2kt7Tsu=43a70846fe67ebce9998ba267f800e6d
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.6.1-61-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-3HRKUVtcYzCDFYtOgvdhxq
key: http-streams-0.8.6.1-3HRKUVtcYzCDFYtOgvdhxq
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 869ed28d4624bd40bba8a4838dd0387e
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-3HRKUVtcYzCDFYtOgvdhxq
depends:
    attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-JXGuJUceANO499VwrM4bRp
    HsOpenSSL-0.11.4.15-H5EoxrBmZ1h1U4vEvi2Hd0
    openssl-streams-1.2.1.3-JbHXdCyvbSh3xuSKkDD4GD mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX
    http-common-0.8.2.0-B6v8GVrwl9jIlEhWqPx0Wz
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.2-2RBwCQfuJsIKkUEqILG4bZ
abi-depends: attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             io-streams-1.5.0.1-JXGuJUceANO499VwrM4bRp=af802af3863ba39b3a6533a3e4aeb506
             HsOpenSSL-0.11.4.15-H5EoxrBmZ1h1U4vEvi2Hd0=bc1a8401393c91eee553657bc6c17eb3
             openssl-streams-1.2.1.3-JbHXdCyvbSh3xuSKkDD4GD=8b11c3e9e2c238a9b34a2435a5f26369
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             unordered-containers-0.2.9.0-KPgljVKoY3VBKTw1tFbcre=264f905ec4c04eb05b5ff3d7321fae90
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             http-common-0.8.2.0-B6v8GVrwl9jIlEhWqPx0Wz=d6191b077f38f636435b6507339ceec4
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             network-2.7.0.2-2RBwCQfuJsIKkUEqILG4bZ=0d494d78cf83103492e5ffc3d4798d79
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
